==> jc-1.4.0.tar.gz: javax/print/attribute/EnumSyntax.h <==
// public abstract class javax.print.attribute.EnumSyntax

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 96da48e7223778b9 javax_print_attribute_EnumSyntax

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_print_attribute_EnumSyntax_H_
#define _JC_javax_print_attribute_EnumSyntax_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_EnumSyntax$sub_refs	_jc_javax_print_attribute_EnumSyntax$sub_refs;
typedef struct _jc_javax_print_attribute_EnumSyntax$sub_nonrefs	_jc_javax_print_attribute_EnumSyntax$sub_nonrefs;
typedef struct _jc_javax_print_attribute_EnumSyntax$refs	_jc_javax_print_attribute_EnumSyntax$refs;
typedef struct _jc_javax_print_attribute_EnumSyntax$nonrefs	_jc_javax_print_attribute_EnumSyntax$nonrefs;
typedef struct _jc_javax_print_attribute_EnumSyntax$object	_jc_javax_print_attribute_EnumSyntax$object;

typedef struct _jc_javax_print_attribute_EnumSyntax$fields_struct	_jc_javax_print_attribute_EnumSyntax$fields_struct;
typedef const struct _jc_javax_print_attribute_EnumSyntax$vmethods	_jc_javax_print_attribute_EnumSyntax$vmethods;
typedef const struct _jc_javax_print_attribute_EnumSyntax$vtable	_jc_javax_print_attribute_EnumSyntax$vtable;
typedef const struct _jc_javax_print_attribute_EnumSyntax$vtype	_jc_javax_print_attribute_EnumSyntax$vtype;

// Class fields structure
struct _jc_javax_print_attribute_EnumSyntax$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_EnumSyntax$fields_struct _jc_javax_print_attribute_EnumSyntax$class_fields;

// Constructors
extern void _jc_javax_print_attribute_EnumSyntax$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *, jint);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_javax_print_attribute_EnumSyntax$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *);
extern _jc_object_array *_jc_javax_print_attribute_EnumSyntax$method$getEnumValueTable$1c85157c59115162(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *);
extern jint _jc_javax_print_attribute_EnumSyntax$method$getOffset$520eb02cb0855546(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *);
extern _jc_object_array *_jc_javax_print_attribute_EnumSyntax$method$getStringTable$8ea8eff83f6eeebe(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *);
extern jint _jc_javax_print_attribute_EnumSyntax$method$getValue$245714dca3f59de3(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *);
extern jint _jc_javax_print_attribute_EnumSyntax$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_EnumSyntax$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_EnumSyntax$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_javax_print_attribute_EnumSyntax$method_info$getEnumValueTable$1c85157c59115162;
extern _jc_method _jc_javax_print_attribute_EnumSyntax$method_info$getOffset$520eb02cb0855546;
extern _jc_method _jc_javax_print_attribute_EnumSyntax$method_info$getStringTable$8ea8eff83f6eeebe;
extern _jc_method _jc_javax_print_attribute_EnumSyntax$method_info$getValue$245714dca3f59de3;
extern _jc_method _jc_javax_print_attribute_EnumSyntax$method_info$hashCode$53152098849316df;
extern _jc_method _jc_javax_print_attribute_EnumSyntax$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_print_attribute_EnumSyntax$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *);
	_jc_object_array	*(*getEnumValueTable$1c85157c59115162)(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *);
	jint	(*getOffset$520eb02cb0855546)(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *);
	_jc_object_array	*(*getStringTable$8ea8eff83f6eeebe)(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *);
	jint	(*getValue$245714dca3f59de3)(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *);
};

// Vtable
struct _jc_javax_print_attribute_EnumSyntax$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_EnumSyntax$vmethods	javax_print_attribute_EnumSyntax;
};

// Vtype
struct _jc_javax_print_attribute_EnumSyntax$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_EnumSyntax$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_EnumSyntax$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_EnumSyntax$refs {
    _jc_javax_print_attribute_EnumSyntax$sub_refs	javax_print_attribute_EnumSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_EnumSyntax$sub_nonrefs {
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_EnumSyntax$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_EnumSyntax$sub_nonrefs	javax_print_attribute_EnumSyntax;
};

// Object instance structure
struct _jc_javax_print_attribute_EnumSyntax$object {
	_jc_javax_print_attribute_EnumSyntax$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_EnumSyntax$vtype	*vtype;
	_jc_javax_print_attribute_EnumSyntax$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_EnumSyntax$vtype _jc_javax_print_attribute_EnumSyntax$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_EnumSyntax, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_EnumSyntax$class_object;

#endif	/* _JC_javax_print_attribute_EnumSyntax_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/EnumSyntax.h <==
// public abstract class javax.print.attribute.EnumSyntax

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 96da48e7223778b9 javax_print_attribute_EnumSyntax

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_print_attribute_EnumSyntax_H_
#define _JC_javax_print_attribute_EnumSyntax_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_EnumSyntax$sub_refs	_jc_javax_print_attribute_EnumSyntax$sub_refs;
typedef struct _jc_javax_print_attribute_EnumSyntax$sub_nonrefs	_jc_javax_print_attribute_EnumSyntax$sub_nonrefs;
typedef struct _jc_javax_print_attribute_EnumSyntax$refs	_jc_javax_print_attribute_EnumSyntax$refs;
typedef struct _jc_javax_print_attribute_EnumSyntax$nonrefs	_jc_javax_print_attribute_EnumSyntax$nonrefs;
typedef struct _jc_javax_print_attribute_EnumSyntax$object	_jc_javax_print_attribute_EnumSyntax$object;

typedef struct _jc_javax_print_attribute_EnumSyntax$fields_struct	_jc_javax_print_attribute_EnumSyntax$fields_struct;
typedef const struct _jc_javax_print_attribute_EnumSyntax$vmethods	_jc_javax_print_attribute_EnumSyntax$vmethods;
typedef const struct _jc_javax_print_attribute_EnumSyntax$vtable	_jc_javax_print_attribute_EnumSyntax$vtable;
typedef const struct _jc_javax_print_attribute_EnumSyntax$vtype	_jc_javax_print_attribute_EnumSyntax$vtype;

// Class fields structure
struct _jc_javax_print_attribute_EnumSyntax$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_EnumSyntax$fields_struct _jc_javax_print_attribute_EnumSyntax$class_fields;

// Constructors
extern void _jc_javax_print_attribute_EnumSyntax$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_javax_print_attribute_EnumSyntax$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_print_attribute_EnumSyntax$method$getEnumValueTable$1c85157c59115162(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_print_attribute_EnumSyntax$method$getOffset$520eb02cb0855546(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_print_attribute_EnumSyntax$method$getStringTable$8ea8eff83f6eeebe(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_print_attribute_EnumSyntax$method$getValue$245714dca3f59de3(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_print_attribute_EnumSyntax$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_EnumSyntax$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_EnumSyntax$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_javax_print_attribute_EnumSyntax$method_info$getEnumValueTable$1c85157c59115162;
extern _jc_method _jc_javax_print_attribute_EnumSyntax$method_info$getOffset$520eb02cb0855546;
extern _jc_method _jc_javax_print_attribute_EnumSyntax$method_info$getStringTable$8ea8eff83f6eeebe;
extern _jc_method _jc_javax_print_attribute_EnumSyntax$method_info$getValue$245714dca3f59de3;
extern _jc_method _jc_javax_print_attribute_EnumSyntax$method_info$hashCode$53152098849316df;
extern _jc_method _jc_javax_print_attribute_EnumSyntax$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_print_attribute_EnumSyntax$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getEnumValueTable$1c85157c59115162)(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *) _JC_JCNI_ATTR;
	jint	(*getOffset$520eb02cb0855546)(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getStringTable$8ea8eff83f6eeebe)(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *) _JC_JCNI_ATTR;
	jint	(*getValue$245714dca3f59de3)(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_print_attribute_EnumSyntax$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_EnumSyntax$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_EnumSyntax$vmethods	javax_print_attribute_EnumSyntax;
};

// Vtype
struct _jc_javax_print_attribute_EnumSyntax$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_EnumSyntax$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_EnumSyntax$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_EnumSyntax$refs {
    _jc_javax_print_attribute_EnumSyntax$sub_refs	javax_print_attribute_EnumSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_EnumSyntax$sub_nonrefs {
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_EnumSyntax$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_EnumSyntax$sub_nonrefs	javax_print_attribute_EnumSyntax;
};

// Object instance structure
struct _jc_javax_print_attribute_EnumSyntax$object {
	_jc_javax_print_attribute_EnumSyntax$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_EnumSyntax$vtype	*vtype;
	_jc_javax_print_attribute_EnumSyntax$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_EnumSyntax$vtype _jc_javax_print_attribute_EnumSyntax$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_EnumSyntax, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_EnumSyntax$class_object;

#endif	/* _JC_javax_print_attribute_EnumSyntax_H_ */
